package cn.com.qmth.run;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

import org.apache.commons.io.IOUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import com.google.common.collect.Maps;

import cn.com.qmth.im.HttpMethod;
import cn.com.qmth.im.OKHttpUtil;
import cn.com.qmth.im.QuestionId;
import cn.com.qmth.param.Param;
import okhttp3.Response;

public class DeleteImportPaperQuestion {

    private static Logger logger = LogManager.getLogger(DeleteImportPaperQuestion.class);

    public static void main(String[] args) {
        logger.debug("**********************删除开始");
        Date start = new Date();

        List<QuestionId> cs = readSubject();
        int index = 0;
        for (QuestionId c : cs) {
            try {
                submit(c);
                index++;
                logger.debug("**********************完成：" + index + " | unit_id:" + c.getUnitId());
            } catch (IOException e) {
                logger.error("删除失败:" + c.getUnitId() + " | " + c.getQuestionId(), e);
            }
        }

        Date end = new Date();
        logger.debug("**********************删除结束  耗时：" + (end.getTime() - start.getTime()));
        OKHttpUtil.close();
    }

    private static List<QuestionId> readSubject() {
        List<QuestionId> list = new ArrayList<>();
        XSSFWorkbook wb = null;
        try {
            wb = new XSSFWorkbook(Param.dataDir + "/duplicatequestion.xlsx");
            XSSFSheet sheet = wb.getSheetAt(0);
            int rows = sheet.getLastRowNum();
            for (int i = 1; i <= rows; i++) {
                XSSFRow row = sheet.getRow(i);
                String valid = row.getCell(9).getStringCellValue().trim();
                if ("否".equals(valid)) {
                    QuestionId c = new QuestionId();
                    String courseCode = row.getCell(1).getStringCellValue().trim();
                    String uid = row.getCell(7).getStringCellValue().trim();
                    String qid = row.getCell(8).getStringCellValue().trim();
                    c.setCourseCode(courseCode);
                    c.setUnitId(uid);
                    c.setQuestionId(qid);
                    list.add(c);
                }
            }
        } catch (IOException e) {
            throw new RuntimeException(e);
        } finally {
            if (wb != null) {
                try {
                    wb.close();
                } catch (IOException e) {
                }
            }
        }
        return list;
    }

    private static void submit(QuestionId ic) throws IOException {
        Map<String, String> params = Maps.newHashMap();
        Map<String, String> headers = Maps.newHashMap();
        headers.put("key", Param.key);
        headers.put("token", Param.token);
        Response resp = null;
        try {
            resp = OKHttpUtil.call(HttpMethod.DELETE,
                    Param.host + "/api/ecs_ques/paper/deleteQuestion/" + ic.getUnitId() + "/" + ic.getQuestionId(),
                    headers, params);
            if (resp.code() != 200) {
                logger.error(ic.getUnitId() + " | " + ic.getQuestionId() + ":body:" + resp.body().string());
                // throw new RuntimeException(ic.getUnitId() + " | " +
                // ic.getQuestionId() + ":body:" + resp.body().string());
            }
        } finally {
            IOUtils.closeQuietly(resp);
        }
    }
}
